TryonBtn class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TryonBtn
Constructors
- TryonBtn({Key? key, Widget? child, bool? isCustom = false, bool? isMagicMirror = false, required String urlPrefix, required String customerId, required String tryOnKey, Decoration? decoration, double? radius = 5, double? fontSize = 15, double? borderWidth = 0.8, Color? borderColor = const Color(0xffe0c448), Color? btnColor = const Color(0xff181d58), Color? txtColor = Colors.white, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 15, vertical: 10), EdgeInsetsGeometry? margin = const EdgeInsets.symmetric(horizontal: 15, vertical: 10), double? height, double? width, String? btnTxt = "TryOn", FontWeight? fontWeight, FontStyle? fontStyle, bool? fromId, String? userId})
-
const
Properties
- borderColor → Color?
-
final
- borderWidth → double?
-
final
- btnColor → Color?
-
final
- btnTxt → String?
-
final
- child → Widget?
-
final
- customerId → String
-
final
- decoration → Decoration?
-
final
- fontSize → double?
-
final
- fontStyle → FontStyle?
-
final
- fontWeight → FontWeight?
-
final
- fromId → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isCustom → bool?
-
final
- isMagicMirror → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry?
-
final
- padding → EdgeInsetsGeometry?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tryOnKey → String
-
final
- txtColor → Color?
-
final
- urlPrefix → String
-
final
- userId → String?
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TryonBtn> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited