ColorConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- errorBgSnackBarColor ↔ Color
-
getter/setter pair
- errorTextSnackBarColor ↔ Color
-
getter/setter pair
- gray ↔ Color
-
getter/setter pair
- pinkColor ↔ Color
-
getter/setter pair
- redColor ↔ Color
-
getter/setter pair
- successBgSnackBarColor ↔ Color
-
getter/setter pair
- successTextSnackBarColor ↔ Color
-
getter/setter pair