ApiResponse<T> class

Constructors

ApiResponse({required bool status, required dynamic message, String? extra, int? statusCode, Map? extraData, required T data})

Properties

data ↔ T
getter/setter pair
extra String?
getter/setter pair
extraData Map?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool
getter/setter pair
statusCode int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited