ApiCall class

Constructors

ApiCall()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

delete(String url, Map<String, dynamic> qParams, dynamic body, {dynamic headers = defaultHeaders}) Future<ApiResponse>
get(String url, Map<String, dynamic> qParams, dynamic body, {dynamic headers = defaultHeaders}) Future<ApiResponse>
post(String url, Map<String, dynamic> qParams, dynamic body, {dynamic headers = defaultHeaders}) Future<ApiResponse>
put(String url, Map<String, dynamic> qParams, dynamic body, {dynamic headers = defaultHeaders}) Future<ApiResponse>

Constants

defaultHeaders → const Map<String, String>