ApiConstants class

Constructors

ApiConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

addUser → const String
addWishlist → const String
baseUrl → const String
getAiData → const String
getCategories → const String
getFilters → const String
getLabels → const String
getMedia → const String
getProducts → const String
getProductsList → const String
getRecommendedProducts → const String
userLookbook → const String
verifyUser → const String