LabelConst class

Constructors

LabelConst()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

btn_txt String
getter/setter pair
content String
getter/setter pair
content_2 String
getter/setter pair
isDemo bool
getter/setter pair
isScanner bool
getter/setter pair
title String
getter/setter pair