FaceModel class

Constructors

FaceModel({String? image, PurpleLandmarks? landmarks, Offsets? offsets, String? type})
FaceModel.fromJson(dynamic json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
image String?
getter/setter pair
landmarks PurpleLandmarks?
getter/setter pair
offsets Offsets?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited