CollectionModel class
Constructors
- CollectionModel({String? collectionId, String? customerId, String? collectionName, String? image, String? sortOrder, String? productCount})
-
CollectionModel.fromJson(Map<
String, dynamic> json)
Properties
- collectionId ↔ String?
-
getter/setter pair
- collectionName ↔ String?
-
getter/setter pair
- customerId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- image ↔ String?
-
getter/setter pair
- productCount ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited