UserProviderWidget class

Inheritance

Constructors

UserProviderWidget({required BuildContext context})

Properties

context BuildContext
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isUserExists bool
getter/setter pair
requiredToAddUser bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setIsUserExists bool
no getter
setRequiredToAddUser bool
no getter
userModel UserModel?
no setter
wishlistProvider WishlistProvider
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addUser({required String name, required String email, required String mobileNumber, required String countryCode}) Future<String>
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
getUserIdFromMobileNumber({required String number, required String name}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
verifyUser({required String mobileNumber, required String countryCode, required BuildContext context}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited