TryOnCollection class
Constructors
-
TryOnCollection({required String id, required String name, required String totalProducts, required List<
String> productList}) - TryOnCollection.fromDashboardCollection(TryOnProductCollection element)
-
factory
-
TryOnCollection.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
-
productList
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalProducts ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited