TryOnPreferences class

Constructors

TryOnPreferences({required JeweltryPref jeweltryPref, required GeneralPref generalPref, required NotificationsPref notificationsPref, String? customerId})
TryOnPreferences.fromJson(Map<String, dynamic> json)
factory

Properties

customerId String?
getter/setter pair
generalPref GeneralPref
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jeweltryPref JeweltryPref
getter/setter pair
notificationsPref NotificationsPref
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited