TryOnProduct class

Constructors

TryOnProduct({required String productId, required String name, required String tryonImage, String? tryonNeckEarring, required String parentCategory, required String tryonType, required String tryonStatus, required String price, String? topLeft, String? uniqueIdentifier, String? topRight, List<String>? aiRecommendedProducts, List<TryOnProduct>? variants, String? objectGlb, String? objectJson, String? object3d, dynamic is3dProduct, String? url3d, String? danglerGlb, String? dangler3d, String? danglerJson})
TryOnProduct.fromJson(Map<String, dynamic> json)
factory

Properties

aiRecommendedProducts List<String>?
getter/setter pair
dangler3d String?
getter/setter pair
danglerGlb String?
getter/setter pair
danglerJson String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
is3dProduct ↔ dynamic
getter/setter pair
name String
getter/setter pair
object3d String?
getter/setter pair
objectGlb String?
getter/setter pair
objectJson String?
getter/setter pair
parentCategory String
getter/setter pair
price String
getter/setter pair
productId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft String?
getter/setter pair
topRight String?
getter/setter pair
tryonImage String
getter/setter pair
tryonNeckEarring String?
getter/setter pair
tryonStatus String
getter/setter pair
tryonType String
getter/setter pair
uniqueIdentifier String?
getter/setter pair
url3d String?
getter/setter pair
variants List<TryOnProduct>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited