ProductTried class

Constructors

ProductTried(String id, String time, String name, String price, String image, String tryon_count)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
image String
getter/setter pair
name String
getter/setter pair
price String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
getter/setter pair
tryon_count String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited