DoubleIcon class

Constructors

DoubleIcon(IconData icon1, IconData icon2)

Properties

hashCode int
The hash code for this object.
no setterinherited
icon1 IconData
getter/setter pair
icon2 IconData
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited