KioskUtils class

Constructors

KioskUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isKiosk(BuildContext context) bool
Returns true if the current screen matches kiosk dimensions.
isMobile(BuildContext context) bool
Convenience: returns true if NOT a kiosk (normal mobile/tablet)