CustominputText class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CustominputText
Constructors
- CustominputText({Key? key, TextEditingController? textEditingController, bool? autoFocus, dynamic onChanged(String)?, bool? isEnabled = true, bool? enableInteractiveSelection, TextInputType? textInputType, bool? showPassword, String? validator(String?)?, TextInputAction? textInputAction, Widget? prefixWidget, Widget? suffixWidget, Color? textInputBackgroundColor, double? borderRadius, String? hintText, EdgeInsets? edgeInsets, FocusNode? focusNode, int? maxLength, int? maxLines, InputBorder? border, String? labelText, bool? alignLabelWithHint, void onFieldSubmitted(String)?, void onTap()?, bool? readOnly})
-
const
Properties
- alignLabelWithHint → bool?
-
final
- autoFocus → bool?
-
final
- border → InputBorder?
-
final
- borderRadius → double?
-
final
- edgeInsets → EdgeInsets?
-
final
- enableInteractiveSelection → bool?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- isEnabled → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- onChanged → dynamic Function(String)?
-
final
- onFieldSubmitted → void Function(String)?
-
final
- onTap → void Function()?
-
final
- prefixWidget → Widget?
-
final
- readOnly → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPassword → bool?
-
final
- suffixWidget → Widget?
-
final
- textEditingController → TextEditingController?
-
final
- textInputAction → TextInputAction?
-
final
- textInputBackgroundColor → Color?
-
final
- textInputType → TextInputType?
-
final
- validator → String? Function(String?)?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited