ApiConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAiModelClothTryonImages(
String customerId) → String
Constants
- addUser → const String
- addWishlist → const String
- aiImageTryonCloth → const String
- aiJewelleryTryon → const String
- baseUrl → const String
- collection → const String
- createCuratedCollection → const String
- curatedCombination → const String
- getCategories → const String
- getFilters → const String
- getLabels → const String
- getMedia → const String
- getModelImages → const String
- getProducts → const String
- getRecommendedProducts → const String
- handleProductTryon → const String
- userLookbook → const String
- verifyUser → const String