HiveConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- hiveCategoryData → const String
- hiveMeet → const String
- hiveMeetData → const String
- hiveProducts → const String
- hiveProductsData → const String
- hiveSales → const String
- hiveSalesLine → const String
- hiveSalesPie → const String
- hiveSalesTop → const String
- hiveUser → const String