Mirror class
Constructors
Properties
- baseUrl ↔ String
-
getter/setter pair
- consentBtnText ↔ String
-
getter/setter pair
- consentDesc1 ↔ String
-
getter/setter pair
- consentDesc2 ↔ String
-
getter/setter pair
- consentTitle ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDemo ↔ bool
-
getter/setter pair
- isScanner ↔ bool
-
getter/setter pair
- noAiProducts ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited