Earring class

Constructors

Earring({double? upDown, double? leftRight, double? leftRightLeft, double? leftRightRight, double? bigSmall, double? rotateAngle})
Earring.fromJson(dynamic json)
factory

Properties

bigSmall double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
leftRight double?
getter/setter pair
leftRightLeft double?
getter/setter pair
leftRightRight double?
getter/setter pair
rotateAngle double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upDown double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited