GeneralPref class
Constructors
-
GeneralPref({required CapturePhoto dangling, required CapturePhoto sparkling, required CapturePhoto feedback, required CapturePhoto pageTour, required CapturePhoto capturePhoto, required CapturePhoto downloadPhoto, List<
String> ? allowedCategories}) -
GeneralPref.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedCategories
↔ List<
String> ? -
getter/setter pair
- capturePhoto ↔ CapturePhoto
-
getter/setter pair
- dangling ↔ CapturePhoto
-
getter/setter pair
- downloadPhoto ↔ CapturePhoto
-
getter/setter pair
- feedback ↔ CapturePhoto
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageTour ↔ CapturePhoto
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
- sparkling ↔ CapturePhoto
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited