JeweltryPref class
Constructors
-
JeweltryPref({required String allowCollections, List<
String> ? collectionsToShow, required String allowAllProductsDisplay, required String allowZooming, required String allowBlush, required String allowBeautify, required String allowLipstick, required String allowModelTryon, required String allowRealtimeTryon, required List<String?> categoriesToShow, required Color primaryColor, required Color secondaryColor, required Color fontColor}) -
JeweltryPref.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowAllProductsDisplay ↔ String
-
getter/setter pair
- allowBeautify ↔ String
-
getter/setter pair
- allowBlush ↔ String
-
getter/setter pair
- allowCollections ↔ String
-
getter/setter pair
- allowLipstick ↔ String
-
getter/setter pair
- allowModelTryon ↔ String
-
getter/setter pair
- allowRealtimeTryon ↔ String
-
getter/setter pair
- allowZooming ↔ String
-
getter/setter pair
-
categoriesToShow
↔ List<
String?> -
getter/setter pair
-
collectionsToShow
↔ List<
String> ? -
getter/setter pair
- fontColor ↔ Color
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor ↔ Color
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor ↔ Color
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited